import { uuid } from "../../common/utilities";

export class Tile {
  id: string;
  pips: [number, number];
  revealed: boolean = true;
  flipped: boolean = false;
  playerId?: string;

  constructor(pips: [number, number]) {
    this.id = uuid();
    this.pips = pips;
  }
  
  get count() {
    return this.pips[0] + this.pips[1];
  }

  get isPair(): boolean {
    return this.pips[0] === this.pips[1];
  }

  get flippedPips(): [number, number] {
    return this.flipped ? [this.pips[1], this.pips[0]] : this.pips;
  }

  flip() {
    this.flipped = !this.flipped;
  }

  getState(showPips: boolean = false) {
    return {
      id: this.id,
      pips: showPips ? this.pips : undefined,
      flipped: this.flipped,
      revealed: this.revealed,
      playerId: this.playerId,
    };
  }

  toString(): string {
    if (!this.revealed) {
      return '[ | ]';
    } else {
      return `[${this.flippedPips[0]}|${this.flippedPips[1]}]`;
    }
  }
}
