import { Request, Response, Router } from 'express';
import { AuthController } from '../controllers/AuthController';
import { UpdaterController } from '../controllers/UpdaterController';

import adminRouter from './adminRouter';
import userRouter from './userRouter';
import gameRouter from './gameRouter';

export default function(): Router {
  const router = Router();
  const authController = new AuthController();
  const updaterController = new UpdaterController();

  router.get('/version', async function(req: Request, res: Response){
      res.json({
        app: 'domino',
        version: '0.1.4-test',
      }).end();
  });

  router.post('/auth/code', (req: Request, res: Response) => authController.twoFactorCodeAuthentication(req, res));
  router.post('/login', (req: Request, res: Response) => authController.login(req, res));
  router.post('/refresh', (req: Request, res: Response) => authController.refresh(req, res));
  router.get('/updater/:target/:arch/:currentVersion', (req: Request, res: Response) => updaterController.checkUpdate(req, res));

  router.use('/admin', adminRouter());
  router.use('/user', userRouter());
  router.use('/game', gameRouter());


  return router;
}
