import { UsersMongoManager } from "../db/mongo/UsersMongoManager";
import { SecurityManager } from "../managers/SecurityManager";
import { ServiceBase } from "./ServiceBase";
import { User } from "../db/interfaces";
import toObjectId from "../db/mongo/common/mongoUtils";

export class UsersService extends ServiceBase {
  usersManager = new UsersMongoManager();
  security = new SecurityManager();

  listUsers(options?: any) {
    if (options) {
      return this.usersManager.getAvailableUsers(options.not);
    }
    return this.usersManager.getUsers();
  }
    
  getUser(id: string) {
    return this.usersManager.getById(id);
  }

  getByUsername(username: string) {
    return this.usersManager.getByUsername(username);
  }

  updateUser(user: any, id: string) {
    const newUser = this._createUserObject(user, id);
    const result = this.usersManager.updateUser(newUser);
    return result;
  }

  updateUserNamespace(userId: string, namespaceId: string) {
    return this.usersManager.updateUserNamespace(userId, namespaceId);
  }

  getById(id: string) {
    return this.usersManager.getById(id);
  }

  createUser(user: any) {
    const newUser = this._createUserObject(user);
    return this.usersManager.addUser(newUser);
  }

  deleteUser(id: string) {
    return this.usersManager.deleteUser(id);
  }

  _createUserObject(body: any, _id?: string) {
    const { username, password, firstname, lastname, email, isadmin, namespaceId, character, roles } = body;
    const id = this.security.generateId();
    const createdAt = new Date().getTime();
    const modifiedAt = createdAt
    // const roles = isadmin ? ['admin', 'user'] : ['user'];

    const user: User = {
      id,
      username,
      password,
      firstname,
      lastname,
      email,
      roles,
      createdAt,
      modifiedAt,
      namespaceId,
      profileId: character,
    };

    this.logger.info(`${password === undefined}`);
    if (_id !== undefined) {
      user._id = _id;
    }

    if (password !== undefined && typeof password === 'string' && password.length > 0) {
      user.hash = this.security.getHashedPassword(password);
      delete user.password;
    }

    return user;
  }
}