import nodemailer, { SentMessageInfo, Transporter } from 'nodemailer';
import hbs from 'nodemailer-express-handlebars';
import Mail from 'nodemailer/lib/mailer';
import SMTPTransport from 'nodemailer/lib/smtp-transport';

export class MailerService {
  transporter: Transporter;
  host: string | undefined;
  sender: string | undefined;
  port: number | undefined;
  user: string | undefined;
  pass: string | undefined;

  constructor() {
    this.transporter = this._createTransporter();
    this.sender = process.env.EMAIL_SENDER;
    this.host = process.env.SMTP_HOST;
    this.port = Number(process.env.SMTP_PORT || 587);
    this.user = process.env.SMTP_USER;
    this.pass = process.env.SMTP_PASS;
    this._configureTemplates();
  }

  _createTransporter():  Transporter {    
      
    return nodemailer.createTransport({
      host: this.host,
      port: this.port,
      secure: false,
      auth: {
        user: this.user,
        pass: this.pass,
      },
    });
  }

  _configureTemplates() {
    this.transporter.use('compile', hbs({
      viewEngine: {
        extname: '.hbs',
        partialsDir: 'app/server/views/partials',
        layoutsDir: 'app/server/views/layouts',
        defaultLayout: 'email.hbs',
      },
      viewPath: 'app/server/views/emails',
      extName: '.hbs',
    }));
  }

  async sendRecoveryPasswordEmail(firstname: string = '', lastname: string = '', email: string, pin: string) {
    const to = firstname ? `${firstname}${lastname ? ' ' + lastname : ''}} <${email}>` : email;
    const mailOptions = {
      from: this.sender,
      to,
      subject: 'Password Recovery',
      template: 'passwordRecovery',
      context: {
        pin,
      },
    };
    return this.send(mailOptions);
  }

  async send(mailOptions: any) {
    return new Promise((resolve, reject) => {
      this.transporter.sendMail(mailOptions, (error, info) => {
        if (error) {
          reject(error);
        } else {
          resolve(info);
        }
      });
    });
  }
}
